### Purpose of this repo
This repo comprises the cm-course-uos python package intended to supplement the Cognitive Modeling Assignments for Students at the University of Osnabrueck. The repository is private to prevent solution leaks. 

### Package updates
With every push to master, a github workflow automatically builds the python package and uploads the package binaries to PyPi. Make sure to increase the version number in `setup.py` before every push to master. Otherwise release on PyPi will be rejected because of duplicat version numbers. 

